@@ -19,14 +19,14 @@
  */
 
 #include "flowtablewithfields.h"
-#include <glom/utility_widgets/datawidget.h>
-#include <glom/utility_widgets/buttonglom.h>
+#include <glom/mode_data/datawidget/datawidget.h>
+#include <glom/mode_data/buttonglom.h>
 #include <glom/utility_widgets/notebookglom.h>
 #include <glom/utility_widgets/notebooklabelglom.h>
 #include <glom/utility_widgets/imageglom.h>
-#include <glom/utility_widgets/labelglom.h>
+#include <glom/mode_data/datawidget/label.h>
 #include <glom/utility_widgets/dialog_flowtable.h>
-#include <glom/utility_widgets/placeholder-glom.h>
+#include <glom/mode_data/placeholder-glom.h>
 #include <glom/application.h>
 #include <gtkmm/checkbutton.h>
 #include <libglom/data_structure/glomconversions.h>
@@ -40,10 +40,11 @@
 #include <glibmm/i18n.h>
 
 namespace Glom
-{
+{	
   
 FlowTableWithFields::Info::Info()
 : m_first(0),
+  m_first_eventbox(0),
   m_second(0),
   m_checkbutton(0)
 {
@@ -248,6 +249,8 @@ void FlowTableWithFields::add_layout_group_at_position(const sharedptr<LayoutGro
     flow_table->signal_related_record_changed().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_related_record_changed) );
     flow_table->signal_requested_related_details().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_requested_related_details) );
     flow_table->signal_script_button_clicked().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_script_button_clicked) );
+    
+    flow_table->align_child_group_labels();
   }
 }
 
@@ -364,7 +367,7 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
     if(group)
     {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-      NotebookLabelGlom* tab_label = Gtk::manage(new NotebookLabelGlom(notebook_widget));
+      NotebookLabel* tab_label = Gtk::manage(new NotebookLabel(notebook_widget));
       tab_label->show();
 #else
       Gtk::Label* tab_label = Gtk::manage(new Gtk::Label());
@@ -556,6 +559,7 @@ void FlowTableWithFields::add_field_at_position(const sharedptr<LayoutItem_Field
   
   Gtk::EventBox* eventbox = Gtk::manage(new Gtk::EventBox());
   eventbox->add(*info.m_first);
+  info.m_first_eventbox = eventbox; //Remember it so we can retrieve the column number later from FlowTable.
   eventbox->set_visible_window(false);
   eventbox->set_events(Gdk::ALL_EVENTS_MASK);
   eventbox->show_all();
@@ -636,7 +640,7 @@ void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_
   alignment_label->show();
   
   const Glib::ustring text = layoutitem_text->get_text();
-  LabelGlom* label = Gtk::manage(new LabelGlom(text));
+  DataWidgetChildren::Label* label = Gtk::manage(new DataWidgetChildren::Label(text));
   label->set_layout_item(layoutitem_text, table_name);
   label->show();
   alignment_label->add(*label);
@@ -660,7 +664,7 @@ void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_
     alignment_title->set(Gtk::ALIGN_RIGHT, Gtk::ALIGN_CENTER);
     alignment_title->show();
 
-    LabelGlom* title_label = Gtk::manage(new LabelGlom(title, 0, 0, false));
+    DataWidgetChildren::Label* title_label = Gtk::manage(new DataWidgetChildren::Label(title, 0, 0, false));
     title_label->set_layout_item(layoutitem_text, table_name);
     title_label->show();
     alignment_title->add(*title_label);
@@ -1242,6 +1246,117 @@ void FlowTableWithFields::on_flowtable_requested_related_details(const Glib::ust
   signal_requested_related_details().emit(table_name, primary_key_value);
 }
 
+void FlowTableWithFields::apply_size_groups_to_labels(const type_vec_sizegroups& size_groups)
+{
+  //Remove widgets from any existing size group:
+  for(type_listFields::iterator iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
+  {
+    Info info = *iter;
+    Gtk::Label* label = info.m_first;
+    Glib::RefPtr<Gtk::SizeGroup> previous_size_group = info.m_first_in_sizegroup;
+    if(!label || !previous_size_group)
+      continue;
+      
+    previous_size_group->remove_widget(*label);
+    info.m_first_in_sizegroup.reset();
+  }
+  
+  m_vec_size_groups = size_groups;
+  
+  if(m_vec_size_groups.empty())
+    return;
+     
+  for(type_listFields::iterator iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
+  {
+    Info info = *iter;
+    Gtk::Label* label = info.m_first;
+    if(!label)
+      continue;
+      
+    Gtk::EventBox* label_parent = info.m_first_eventbox;
+    if(!label_parent)
+      continue;
+            
+    //Only align labels in the first column, because items in separate columns 
+    //couldn't be aligned vertically anyway, and this would cause extra space.
+    //TODO: Use a different SizeGroup for items in 2nd columns?
+    guint column = 0;
+    const bool column_allocated = get_column_for_first_widget(*label_parent, column);
+    if(!column_allocated)
+      
+    if(column >= m_vec_size_groups.size())
+      continue;
+      
+    Glib::RefPtr<Gtk::SizeGroup> size_group = m_vec_size_groups[column];
+    if(size_group && (info.m_first_in_sizegroup != size_group))
+    {
+      size_group->add_widget(*label);
+      info.m_first_in_sizegroup = size_group; //Remember it so we can remove it later.
+    }
+  } 
+}
+
+void FlowTableWithFields::align_child_group_labels()
+{
+  //Don't bother if there are not >1 groups to align:
+  if(m_sub_flow_tables.size() < 2)
+    return;
+    
+  //Create a size group for each column and tell all groups to use them for their labels:
+  const guint max_columns = get_sub_flowtables_max_columns();
+  type_vec_sizegroups vec_sizegroups(max_columns);
+  for(guint i = 0; i < max_columns; ++i)
+  {
+    vec_sizegroups[i] = Gtk::SizeGroup::create(Gtk::SIZE_GROUP_HORIZONTAL);
+  }
+   
+  for(type_sub_flow_tables::iterator iter = m_sub_flow_tables.begin(); iter != m_sub_flow_tables.end(); ++iter)
+  {
+    FlowTableWithFields* subtable = *iter;
+    if(subtable)
+      subtable->apply_size_groups_to_labels(vec_sizegroups);
+  }
+}
+
+guint FlowTableWithFields::get_sub_flowtables_max_columns() const
+{
+  guint result = get_columns_count();
+  
+  for(type_sub_flow_tables::const_iterator iter = m_sub_flow_tables.begin(); iter != m_sub_flow_tables.end(); ++iter)
+  {
+    const FlowTableWithFields* subtable = *iter;
+    if(subtable)
+    {
+      const guint count = subtable->get_columns_count();
+      if(count > result)
+          result = count;
+    }
+  }
+  
+  return result;
+}
+  
+
+void FlowTableWithFields::on_size_allocate(Gtk::Allocation& allocation)
+{
+  FlowTable::on_size_allocate(allocation);
+  
+  sharedptr<const LayoutGroup> group = get_layout_group();
+  Glib::ustring group_name;
+  if(group)
+     group_name = group->get_name();
+
+  //The widgets have now been allocated their sizes and columns, 
+  //so this should be able to work:
+  if(m_columns_allocated_changed)
+  {
+    apply_size_groups_to_labels(m_vec_size_groups);
+    
+    //Prevent unnecessary repeated (endless?) size allocation requested:
+    m_columns_allocated_changed = false;
+  }
+}
+  
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 
 void FlowTableWithFields::on_dnd_add_layout_item_by_type(int item_type_num, Gtk::Widget* above_widget)
@@ -1470,32 +1585,21 @@ bool FlowTableWithFields::dnd_add_to_layout_group(const sharedptr<LayoutItem>& i
 
 void FlowTableWithFields::on_menu_properties_activate()
 {
-  try
+  Dialog_FlowTable* dialog = 0;
+  Utils::get_glade_widget_derived_with_warning(dialog);
+  
+  dialog->set_flowtable(this);
+  const int response = dialog->run();
+  if(response == Gtk::RESPONSE_OK)
   {
-    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_flowtable");
-
-    Dialog_FlowTable* dialog = 0;
-    refXml->get_widget_derived("dialog_flowtable", dialog);
-
-    if(dialog)
-    {
-      dialog->set_flowtable(this);
-      const int response = dialog->run();
-      if(response == Gtk::RESPONSE_OK)
-      {
-        sharedptr<LayoutGroup> group = get_layout_group();
-        group->set_columns_count( dialog->get_columns_count() );
-        group->set_title(dialog->get_title());
-        signal_layout_changed().emit();
-      }
-
-      delete dialog;
-    }
-  }
-  catch(const Gtk::BuilderError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
+    sharedptr<LayoutGroup> group = get_layout_group();
+    group->set_columns_count( dialog->get_columns_count() );
+    group->set_title(dialog->get_title());
+    signal_layout_changed().emit();
   }
+
+  delete dialog;
+ 
 }
 
 void FlowTableWithFields::on_menu_delete_activate()
@@ -1531,7 +1635,7 @@ bool FlowTableWithFields::on_button_press_event(GdkEventButton *event)
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
-    gdk_window_get_pointer( Gtk::Widget::gobj()->window, 0, 0, &mods );
+    gdk_window_get_pointer( gtk_widget_get_window (Gtk::Widget::gobj()), 0, 0, &mods );
     if(mods & GDK_BUTTON3_MASK)
     {
       //Give user choices of actions on this item:
@@ -1544,39 +1648,28 @@ bool FlowTableWithFields::on_button_press_event(GdkEventButton *event)
 
 sharedptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship()
 {
-  try
+  Dialog_ChooseRelationship* dialog = 0;
+  Utils::get_glade_widget_derived_with_warning(dialog);
+    
+  Document* pDocument = static_cast<Document*>(get_document());
+  dialog->set_document(pDocument, m_table_name);
+  //TODO: dialog->set_transient_for(*get_app_window());
+  const int response = dialog->run();
+  dialog->hide();
+  if(response == Gtk::RESPONSE_OK)
   {
-    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
-    
-    Dialog_ChooseRelationship* dialog = 0;
-    refXml->get_widget_derived("dialog_choose_relationship", dialog);
-    
-    if(dialog)
+    //Get the chosen relationship:
+    sharedptr<Relationship> relationship  = dialog->get_relationship_chosen();
+    if(relationship)
     {
-      Document* pDocument = static_cast<Document*>(get_document());
-      dialog->set_document(pDocument, m_table_name);
-      //TODO: dialog->set_transient_for(*get_app_window());
-      const int response = dialog->run();
-      dialog->hide();
-      if(response == Gtk::RESPONSE_OK)
-      {
-        //Get the chosen relationship:
-        sharedptr<Relationship> relationship  = dialog->get_relationship_chosen();
-        if(relationship)
-        {
-          sharedptr<LayoutItem_Portal> layout_item = sharedptr<LayoutItem_Portal>::create();
-          layout_item->set_relationship(relationship);
-          return layout_item;
-        }
-      }
-      
+      sharedptr<LayoutItem_Portal> layout_item = sharedptr<LayoutItem_Portal>::create();
+      layout_item->set_relationship(relationship);
       delete dialog;
+      return layout_item;
     }
   }
-  catch(const Gtk::BuilderError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
-  }
+      
+  delete dialog;
   return sharedptr<LayoutItem_Portal>();
 }
 
