@@ -29,7 +29,7 @@
 #include <glom/utils_ui.h>
 #include "cellrenderer_buttonimage.h"
 #include "cellrenderer_buttontext.h"
-#include <glom/utility_widgets/imageglom.h> //For ImageGlom::scale_keeping_ratio().
+#include <glom/utils_ui.h> //For Utils::image_scale_keeping_ratio().
 
 #include <iostream> //For debug output.
 #include <gtk/gtktreeview.h>
@@ -163,7 +163,7 @@ DbAddDel::DbAddDel()
 DbAddDel::~DbAddDel()
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp)
   {
     pApp->remove_developer_action(m_refContextLayout);
@@ -278,7 +278,7 @@ void DbAddDel::setup_menu()
     sigc::mem_fun(*this, &DbAddDel::on_MenuPopup_activate_layout) );
 
   //TODO: This does not work until this widget is in a container in the window:
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -352,7 +352,7 @@ bool DbAddDel::on_button_press_event_Popup(GdkEventButton *event)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Enable/Disable items.
   //We did this earlier, but get_application is more likely to work now:
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
@@ -361,7 +361,7 @@ bool DbAddDel::on_button_press_event_Popup(GdkEventButton *event)
 #endif
 
   GdkModifierType mods;
-  gdk_window_get_pointer( Gtk::Widget::gobj()->window, 0, 0, &mods );
+  gdk_window_get_pointer( gtk_widget_get_window (Gtk::Widget::gobj()), 0, 0, &mods );
   if(mods & GDK_BUTTON3_MASK)
   {
     //Give user choices of actions on this item:
@@ -727,7 +727,9 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
         if(item_field->get_formatting_used().get_has_choices())
         {
           CellRendererList* rendererList = Gtk::manage( new CellRendererList() );
-          rendererList->set_restrict_values_to_list(item_field->get_formatting_used().get_choices_restricted());
+          bool as_radio_buttons = false; //Can't really be done in a list, so we ignore it.
+          rendererList->set_restrict_values_to_list(
+            item_field->get_formatting_used().get_choices_restricted(as_radio_buttons));
 
           pCellRenderer = rendererList;
         }
@@ -2297,7 +2299,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
          
             //Scale it down to a sensible size.
             if(pixbuf)
-              pixbuf = ImageGlom::scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
+              pixbuf = Utils::image_scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
 
             g_object_set(pDerived->gobj(), "pixbuf", pixbuf ? pixbuf->gobj() : 0, (gpointer)0);
           }
@@ -2336,12 +2338,12 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
   }
 }
 
-App_Glom* DbAddDel::get_application()
+Application* DbAddDel::get_application()
 {
   Gtk::Container* pWindow = get_toplevel();
   //TODO: This only works when the child widget is already in its parent.
 
-  return dynamic_cast<App_Glom*>(pWindow);
+  return dynamic_cast<Application*>(pWindow);
 }
 
 void DbAddDel::set_allow_view(bool val)
@@ -2627,7 +2629,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
     //Tell user that they can't do that:
     Gtk::MessageDialog dialog(Utils::bold_message(_("Extra Related Records Not Possible")), true, Gtk::MESSAGE_WARNING);
     dialog.set_secondary_text(_("You attempted to add a new related record, but there can only be one related record, because the relationship uses a unique key.")),
-    dialog.set_transient_for(*App_Glom::get_application());
+    dialog.set_transient_for(*Application::get_application());
     dialog.run();
     
     return;
