@@ -21,16 +21,16 @@
 #ifndef GLOM_MODE_DATA_LAYOUT_WIDGET_BASE_H
 #define GLOM_MODE_DATA_LAYOUT_WIDGET_BASE_H
 
-#include <glom/libglom/data_structure/layout/layoutitem.h>
+#include <libglom/data_structure/layout/layoutitem.h>
 #include <gtkmm.h>
-#include "../mode_data/treestore_layout.h" //Forthe enum.
+#include <glom/mode_design/layout/treestore_layout.h> //Forthe enum.
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 namespace Glom
 {
 
-class App_Glom;
+class Application;
 
 class LayoutWidgetBase : virtual public sigc::trackable
 {
@@ -84,13 +84,19 @@ public:
 #endif // !GLOM_ENABLE_CLIENT_ONLY
     
 protected:
-  virtual App_Glom* get_application() const; // = 0;
+  virtual Application* get_application() const; // = 0;
 
-  static void apply_formatting(Gtk::Widget& widget, const FieldFormatting& formatting);
 
+  static void apply_formatting(Gtk::Widget& widget, const sharedptr<const LayoutItem_WithFormatting>& layout_item);
+
+protected: //TODO: Add accessor?
   sharedptr<LayoutItem> m_pLayoutItem;
+
+protected: //TODO: Add accessor?
   Glib::ustring m_table_name;
 
+private:
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   /// Signals that the layout has changed, so it should be saved to the document again.
   type_signal_layout_changed m_signal_layout_changed;
