@@ -52,8 +52,24 @@ enum DefaultSpacings
   #endif //GLOM_ENABLE_MAEMO
 };
 
+/**
+ * Show the dialog, blocking until there is a non-help response,
+ * showing the appropriate help page if the help button is clicked.
+ */ 
 int dialog_run_with_help(Gtk::Dialog* dialog, const Glib::ustring& id = Glib::ustring());
 
+/**
+ * Show the dialog, blocking until there is a non-help response,
+ * showing the appropriate help page if the help button is clicked.
+ *  This requires the dialog class to have a static 
+ * glade_id member variable, which we reuse as the help ID.
+ */ 
+template<class T_Dialog>
+int dialog_run_with_help(T_Dialog* dialog)
+{
+  return dialog_run_with_help(dialog, T_Dialog::glade_id);
+}
+
 // Maemo has no help system since Maemo 5 (Fremantle).
 #ifndef GLOM_ENABLE_MAEMO
 /** This is a replacement for gnome_help_display(), 
@@ -85,6 +101,8 @@ int get_suitable_field_width_for_widget(Gtk::Widget& widget, const sharedptr<con
 /// Add the @a extension if no extension is there already:
 std::string get_filepath_with_extension(const std::string& filepath, const std::string& extension);
 
+Glib::RefPtr<Gdk::Pixbuf> image_scale_keeping_ratio(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf, int target_height, int target_width);
+  
 } //namespace Utils
 
 } //namespace Glom
